require('dotenv').config();
const path = require('path');
const fs = require('fs');
const client = require('strapi-client');
const moment = require('moment');
const config = require('./config.json')

const buildHash = moment.utc().format('YYYYMMDD.HHmmss');

const dataPath = path.resolve(__dirname, `../data/${buildHash}`)
const mediaPath = path.resolve(__dirname, `../media`)

if (!fs.existsSync(dataPath)) {
	fs.mkdirSync(dataPath, {recursive: true});
}
if (!fs.existsSync(mediaPath)) {
	fs.mkdirSync(mediaPath);
}

client.fetch(config, process.env.GATEWAY_URL, process.env.GATEWAY_TOKEN)
	.then(response => {
		/** Prevent downloading existing resources **/
		const existedMedia = fs.readdirSync(mediaPath);
		response = {
			...response, ...{
				uploadFiles: response.uploadFiles.filter(item => !(existedMedia.includes(`${item.hash}${item.ext}`)))
			}
		}
		client.write(response, config, process.env.GATEWAY_MEDIA, process.env.GATEWAY_TOKEN, dataPath, mediaPath)
			.then(() => {
				fs.writeFile(`.buildhash`, buildHash, err => {
					if (err) {
						throw new Error(`Failed to store the buildhash: ${err}`);
					} else {
						console.log(`\nbuildhash: ${buildHash}`);
					}
				});
			})
	})
	.catch(error => {
		console.error(`Fetching error: ${error}`);
	});
